%global checkout 20150915git

%define rel 4

Summary:	The basic tools for setting up networking
Name:		net-tools
Version:	2.0
Release:	%mkrel -c %{checkout} %{rel}
License:	GPLv2+
Group:		System/Networking
URL:		http://www.tazenda.demon.co.uk/phil/net-tools/
# git archive --format=tar --remote=git://git.code.sf.net/p/net-tools/code master | xz > net-tools-%%{version}.%%{checkout}.tar.xz
Source0:	net-tools-%{version}.%{checkout}.tar.xz
Source1: 	net-tools-config.h
Source2: 	net-tools-config.make
Source3: 	ether-wake.c
Source4: 	ether-wake.8
Source5: 	mii-diag.c
Source6: 	mii-diag.8
Source7: 	iptunnel.8
Source8: 	ipmaddr.8
Source9: 	arp-ethers.service
Source10: 	arp-ethers-tempfiles.conf

# adds <delay> option that allows netstat to cycle printing through statistics every delay seconds.
Patch1: net-tools-cycle.patch

# various man page fixes merged into one patch
Patch2: net-tools-man.patch

# netstat: interface option now works as described in the man page (#61113, #115987)
Patch3: net-tools-interface.patch

# filter out duplicate tcp entries (#139407)
Patch4: net-tools-duplicate-tcp.patch

# don't report statistics for virtual devices (#143981)
Patch5: net-tools-statalias.patch

# clear static buffers in interface.c by Ulrich Drepper (#176714)
Patch6: net-tools-interface_stack.patch

# ifconfig crash when interface name is too long (#190703)
Patch7: net-tools-ifconfig-long-iface-crasher.patch

# use all interfaces instead of default (#1003875)
Patch20: ether-wake-interfaces.patch

# Fix build with kernel 4.8 headers
Patch21: net-tools-linux48.patch

BuildRequires: gettext
Requires(post): systemd-units

%description
The net-tools package contains basic networking tools,
including ifconfig, netstat, route, and others.
Most of them are obsolete. For replacement check iproute2 package.

%prep
%setup -q -c
%patch1 -p1 -b .cycle
%patch2 -p1 -b .man
%patch3 -p1 -b .interface
%patch4 -p1 -b .dup-tcp
%patch5 -p1 -b .statalias
%patch6 -p1 -b .stack
%patch7 -p1 -b .long_iface

cp %{SOURCE1} ./config.h
cp %{SOURCE2} ./config.make
cp %{SOURCE3} .
cp %{SOURCE4} ./man/en_US
cp %{SOURCE5} .
cp %{SOURCE6} ./man/en_US
cp %{SOURCE7} ./man/en_US
cp %{SOURCE8} ./man/en_US

%patch20 -p1 -b .interfaces
%patch21 -p1 -b .linux48

touch ./config.h

%build
export CFLAGS="${RPM_OPT_FLAGS} -fpie"
export LDFLAGS="${RPM_LD_FLAGS} -pie -Wl,-z,now"

make
make ether-wake
gcc ${RPM_OPT_FLAGS} -o mii-diag mii-diag.c

%install
mv man/de_DE man/de
mv man/fr_FR man/fr
mv man/pt_BR man/pt

make BASEDIR=%{buildroot} mandir=%{_mandir} install
mv %{buildroot}/bin %{buildroot}%{_bindir}
mv %{buildroot}/sbin %{buildroot}/%{_sbindir}

# ifconfig and route are installed into /usr/bin by default
# mv them back to /usr/sbin (#1045445)
mv %{buildroot}%{_bindir}/ifconfig %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/route %{buildroot}%{_sbindir}

install -m 755 ether-wake %{buildroot}/%{_sbindir}
install -m 755 mii-diag %{buildroot}/%{_sbindir}

rm %{buildroot}%{_sbindir}/rarp
rm %{buildroot}%{_mandir}/man8/rarp.8*
rm %{buildroot}%{_mandir}/de/man8/rarp.8*
rm %{buildroot}%{_mandir}/fr/man8/rarp.8*
rm %{buildroot}%{_mandir}/pt/man8/rarp.8*

## remove hostname, it has its own package)
rm %{buildroot}%{_bindir}/dnsdomainname
rm %{buildroot}%{_bindir}/domainname
rm %{buildroot}%{_bindir}/hostname
rm %{buildroot}%{_bindir}/nisdomainname
rm %{buildroot}%{_bindir}/ypdomainname
rm -rf %{buildroot}%{_mandir}/de/man1
rm -rf %{buildroot}%{_mandir}/fr/man1
rm -rf %{buildroot}%{_mandir}/man1
rm -rf %{buildroot}%{_mandir}/pt/man1

# install systemd unit file
mkdir -p %{buildroot}%{_unitdir}
%{__install} -D -p -m 644 %{SOURCE9} %{buildroot}%{_unitdir}/arp-ethers.service

%find_lang %{name} --all-name --with-man

### We may add this in the future
##%post
##%_post_service   arp-ethers
 
##%preun
##%_preun_service  arp-ethers

%files -f %{name}.lang
%doc
%license COPYING
%{_bindir}/netstat
%{_sbindir}/ifconfig
%{_sbindir}/route
%{_sbindir}/arp
%{_sbindir}/ether-wake
%{_sbindir}/ipmaddr
%{_sbindir}/iptunnel
%{_sbindir}/mii-diag
%{_sbindir}/mii-tool
%{_sbindir}/nameif
%{_sbindir}/plipconfig
%{_sbindir}/slattach
%{_mandir}/man[158]/*
%attr(0644,root,root) %{_unitdir}/arp-ethers.service


%changelog
* Sat Dec 10 2016 wally <wally> 2.0-0.20150915git.4.mga6
+ Revision: 1073959
- fix description

* Sat Oct 15 2016 pterjan <pterjan> 2.0-0.20150915git.3.mga6
+ Revision: 1060862
- Fix build with kernel 4.8 headers

* Fri Feb 12 2016 umeabot <umeabot> 2.0-0.20150915git.2.mga6
+ Revision: 956243
- Mageia 6 Mass Rebuild

* Fri Oct 09 2015 luigiwalser <luigiwalser> 2.0-0.20150915git.1.mga6
+ Revision: 888381
- update to 20150915 (sync with fedora)
- do not build against selinux

* Fri Sep 11 2015 blino <blino> 2.0-0.20140707git.8.mga6
+ Revision: 878303
- do not require systemd-units (to ease bootstrap on ARM), _unitdir macro is in rpm-mageia-setup-build

* Fri Aug 21 2015 tmb <tmb> 2.0-0.20140707git.7.mga6
+ Revision: 867820
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 2.0-0.20140707git.6.mga5
+ Revision: 743583
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.0-0.20140707git.5.mga5
+ Revision: 682837
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 spuhler <spuhler> 2.0-0.20140707git.4.mga5
+ Revision: 673820
- removing hostname commands
  * we have them now in a new package: hostname

* Sun Sep 07 2014 spuhler <spuhler> 2.0-0.20140707git.3.mga5
+ Revision: 673377
- removed in install %%{_tmpfilesdir}/arp-ethers.conf
- removed the %%preun section
- removed the %%post section
  * we don't want to start the arp-service as a default
- removed the tempfiles
- changed the tempfilesin source to use root root in case we want to use them later
  * the service would run as root

* Sun Sep 07 2014 spuhler <spuhler> 2.0-0.20140707git.2.mga5
+ Revision: 673345
- added missing %%_tmpfilescreate in %%post
- removed the obsolete Conflicts: apparmor-profiles

* Sun Sep 07 2014 spuhler <spuhler> 2.0-0.20140707git.1.mga5
+ Revision: 673083
- corrected the macro in Release:
- corrected the names in teh %%post script (.service)

* Sun Sep 07 2014 spuhler <spuhler> 2.0-0.27.20140707git.mga5
+ Revision: 673024
- upgrded to version 2.0-20140707git
- removed bin.netstat.apparmor
- synched spec file with Fedora, but left the Mageia specific
  hostname commands in this package vs. Fedora having a hostname package
- removed about 85 patch files and a few sources not used anymore
- corrected syntax in .c files
- added sourcefiles from Fedora
- added tempfiles for systemd

* Sat Oct 19 2013 umeabot <umeabot> 1.60-38.mga4
+ Revision: 530339
- Mageia 4 Mass Rebuild

* Mon Jul 22 2013 danf <danf> 1.60-37.mga4
+ Revision: 457336
- fixed corrupted fr ifconfig manpage with mga-man-syntax.patch (mga#10042)
- license is more specifically GPLv2+

* Tue Jan 22 2013 fwang <fwang> 1.60-36.mga3
+ Revision: 390928
- update rpm group

* Tue Jan 15 2013 fwang <fwang> 1.60-35.mga3
+ Revision: 388179
- disable more
- * move to /usr
  * disable HWSTRIP as it doesnot build with latest kernel

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + dmorgan <dmorgan>
    - Own %%{_sysconfdir}/apparmor.d

  + tmb <tmb>
    - imported package net-tools


* Sat Jan  07 2011 Thomas Backlund <tmb@mageia.org> 1.60-33.mga1
- initial import
- drop rpm tags
- rename Mandriva to Mageia

* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1.60-33mdv2011.0
+ Revision: 606818
- rebuild

* Sat Dec 12 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.60-32mdv2010.1
+ Revision: 477635
- sync patch set with fedora

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 1.60-31mdv2010.0
+ Revision: 426250
- rebuild

* Tue Feb 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.60-30mdv2009.1
+ Revision: 337202
- keep bash completion in its own package

* Mon Dec 22 2008 Oden Eriksson <oeriksson@mandriva.com> 1.60-29mdv2009.1
+ Revision: 317504
- rediffed some fuzzy patches
- fix build with -Werror=format-security (P65)
- use %%ldflags

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 1.60-28mdv2009.0
+ Revision: 223344
- rebuild

* Thu Mar 06 2008 Andreas Hasenack <andreas@mandriva.com> 1.60-27mdv2008.1
+ Revision: 181083
- adjust bin.netstat profile so netstat -p works

* Thu Feb 28 2008 Andreas Hasenack <andreas@mandriva.com> 1.60-26mdv2008.1
+ Revision: 176459
- updated apparmor profile for netstat

* Wed Feb 27 2008 Olivier Blin <oblin@mandriva.com> 1.60-25mdv2008.1
+ Revision: 175721
- sync with RH patches (should fix stack smashing with ifconfig/netstat, #34220)
- do not check if buildroot is /

* Fri Feb 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.60-24mdv2008.1
+ Revision: 168917
- fix bash completion

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 1.60-23mdv2008.1
+ Revision: 153282
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Sep 19 2007 Andreas Hasenack <andreas@mandriva.com> 1.60-21mdv2008.0
+ Revision: 91194
- ship apparmor profile and use it if apparmor is in effect

* Wed Aug 29 2007 Oden Eriksson <oeriksson@mandriva.com> 1.60-20mdv2008.0
+ Revision: 74521
- added one hunk in net-tools-1.60-netdevice.patch from fc8


* Sun Jan 14 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.60-19mdv2007.0
+ Revision: 108811
- uncompress all patches and additional sources
- add bash completion
- Import net-tools

* Fri Jan 27 2006 Olivier Blin <oblin@mandriva.com> 1.60-18mdk
- split out netplug, we don't want it by default

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 1.60-17mdk
- fix typo in initscript

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 1.60-16mdk
- convert parallel init to LSB

* Tue Jan 03 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.60-15mdk
- patch 42: add support for parallel init
- disable parallel build (broken)

* Mon Nov 21 2005 Oden Eriksson <oeriksson@mandriva.com> 1.60-14mdk
- drop P0 (netplug_def_runlevel) as we don't want to start 
  it by default

* Mon Jul 25 2005 Olivier Blin <oblin@mandriva.com> 1.60-13mdk
- remove translated rarp man pages (obsolete, #12238)

* Tue Jun 21 2005 Oden Eriksson <oeriksson@mandriva.com> 1.60-12mdk
- sync with fedora (1.60-54)
- added P0 (netplug_def_runlevel)
- misc rpmlint fixes

* Wed Jun 09 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 1.60-11mdk
- fix gcc-3.4 build (P15)
- fix non-conffile-in-etc
- spec cosmetics

* Mon Mar 15 2004 Florin <florin@mandrakesoft.com> 1.60-10mdk
- merge with RH
- add the x25 patch (gb)

